@@ -1039,8 +1039,8 @@ external program defined by `sendmail-program'."
 \\|^resent-cc:\\|^resent-bcc:"
 				   delimline t))
 	      (let* ((default-directory "/")
-		     ;; XEmacs: commented out #### why?
-;		     (coding-system-for-write selected-coding)
+		     ;; XEmacs: changed to no-conversion-unix
+		     (coding-system-for-write 'no-conversion-unix)
 		     (args
 		      (append (list (point-min) (point-max)
 				    program
@@ -1214,7 +1214,12 @@ external program defined by `sendmail-program'."
 		;; convert the message to Babyl format.
 		(let ((coding-system-for-write
 		       (or rmail-file-coding-system
-			   'emacs-mule)))
+			   ;; XEmacs change; emacs-mule is not available,
+			   ;; escape-quoted serves much the same
+			   ;; purpose. #### This means an incompatibility
+			   ;; with Babyl files created with GNU Emacs, but
+			   ;; that's probably okay, since no-one uses them.
+			   'escape-quoted)))
 		  (save-excursion
 		    (set-buffer (get-buffer-create " mail-temp"))
 		    (setq buffer-read-only nil)
@@ -1225,8 +1230,16 @@ external program defined by `sendmail-program'."
 		    (insert "\n\C-_")
 		    (write-region (point-min) (point-max) (car fcc-list) t)
 		    (erase-buffer)))
-	      (write-region
-	       (1+ (point-min)) (point-max) (car fcc-list) t)))
+	      ;; MIME processing should have eliminated any characters
+	      ;; outside the range 0-255; if MIME processing hasn't been
+	      ;; done, there's no reasonable expectation that the data will
+	      ;; be preserved in a Unix mailbox, so we just write tildes for
+	      ;; those chars. We set the coding system for write to 'binary
+	      ;; to prevent any double-encoding that may occur if
+	      ;; buffer-file-coding-system has been initialised to a
+	      ;; non-binary-compatible coding system like, say, UTF-8.
+	      (let ((coding-system-for-write 'binary))
+		(write-region (1+ (point-min)) (point-max) (car fcc-list) t))))
 	  (and buffer (not dont-write-the-file)
 	       (with-current-buffer buffer
 		 (set-visited-file-modtime))))
@@ -1739,7 +1752,9 @@ The seventh argument ACTIONS is a list of actions to take
       (define-key (current-local-map) "v"
 	(lambda ()
 	  (interactive)
-	  (let ((coding-system-for-read 'emacs-mule-unix))
+	  ;; XEmacs change; emacs-mule is not available, escape-quoted
+	  ;; serves the same purpose.
+	  (let ((coding-system-for-read 'escape-quoted))
 	    (dired-view-file))))
       (define-key (current-local-map) "\C-c\C-c"
 	(lambda ()
@@ -1747,19 +1762,21 @@ The seventh argument ACTIONS is a list of actions to take
 	  (let ((fname (dired-get-filename))
 		;; Auto-saved files are written in the internal
 		;; representation, so they should be read accordingly.
-		(coding-system-for-read 'emacs-mule-unix))
+		;; XEmacs change; emacs-mule is not available, escape-quoted
+		;; serves the same purpose.
+		(coding-system-for-read 'escape-quoted))
 	    (switch-to-buffer-other-window "*mail*")
 	    (let ((buffer-read-only nil))
 	      (erase-buffer)
 	      (insert-file-contents fname nil)
-	      ;; insert-file-contents will set buffer-file-coding-system
-	      ;; to emacs-mule, which is probably not what they want to
-	      ;; use for sending the message.  But we don't know what
-	      ;; was its value before the buffer was killed or Emacs
-	      ;; crashed.  We therefore reset buffer-file-coding-system
-	      ;; to the default value, so that either the default does
-	      ;; TRT, or the user will get prompted for the right
-	      ;; encoding when they send the message.
+	      ;; insert-file-contents will set buffer-file-coding-system to
+	      ;; escape-quoted on XEmacs, which is not what they want to use
+	      ;; for sending the message.  But we don't know what was its
+	      ;; value before the buffer was killed or Emacs crashed.  We
+	      ;; therefore reset buffer-file-coding-system to the default
+	      ;; value, so that either the default does TRT, or the user
+	      ;; will get prompted for the right encoding when they send the
+	      ;; message.
 	      (setq buffer-file-coding-system
 		    default-buffer-file-coding-system))))))))
 
@@ -1804,7 +1821,9 @@ you can move to one of them and type C-c C-c to recover that one."
 		     (buffer-coding buffer-file-coding-system)
 		     ;; Auto-save files are written in internal
 		     ;; representation of non-ASCII characters.
-		     (coding-system-for-read 'emacs-mule-unix))
+		     ;; XEmacs change; emacs-mule is not available,
+		     ;; escape-quoted serves the same purpose. 
+		     (coding-system-for-read 'escape-quoted))
 		 (erase-buffer)
 		 (insert-file-contents file-name nil)
 		 (setq buffer-file-coding-system buffer-coding)))))
